@@ -192,25 +192,43 @@ DATE_CALC_TEST_CASES = (
                     (Duration(years=1, months=1, weeks=5),
                      date(2000, 1, 30),
                      date(2001, 4, 4)),
-                    (Duration(years=1, months=1, weeks=5),
-                     'raise exception',
-                     None),
-                    ('raise exception',
-                     Duration(years=1, months=1, weeks=5),
+                    (parse_duration("P1Y1M5W"),
+                     date(2000, 1, 30),
+                     date(2001, 4, 4)),
+                    (parse_duration("P0.5Y"),
+                     date(2000, 1, 30),
                      None),
+                    (Duration(years=1, months=1, hours=3),
+                     datetime(2000, 1, 30, 12, 15, 00),
+                     datetime(2001, 2, 28, 15, 15, 00)),
+                    (parse_duration("P1Y1MT3H"),
+                     datetime(2000, 1, 30, 12, 15, 00),
+                     datetime(2001, 2, 28, 15, 15, 00)),
                     (Duration(years=1, months=2),
                      timedelta(days=1),
                      Duration(years=1, months=2, days=1)),
                     (timedelta(days=1),
                      Duration(years=1, months=2),
                      Duration(years=1, months=2, days=1)),
-                    #(date(2000, 1, 1),
-                    # Duration(years=1.5),
-                    # date(2001, 6, 1)),
-                    #(date(2000, 1, 1),
-                    # Duration(years=1, months=1.5),
-                    # date(2001, 2, 14)),
-                     )
+                    (datetime(2008, 1, 1, 0, 2),
+                     Duration(months=1),
+                     datetime(2008, 2, 1, 0, 2)),
+                    (datetime.strptime("200802", "%Y%M"),
+                     parse_duration("P1M"),
+                     datetime(2008, 2, 1, 0, 2)),
+                    (datetime(2008, 2, 1),
+                     Duration(months=1),
+                     datetime(2008, 3, 1)),
+                    (datetime.strptime("200802", "%Y%m"),
+                     parse_duration("P1M"),
+                     datetime(2008, 3, 1)),
+                    # (date(2000, 1, 1),
+                    #  Duration(years=1.5),
+                    #  date(2001, 6, 1)),
+                    # (date(2000, 1, 1),
+                    #  Duration(years=1, months=1.5),
+                    #  date(2001, 2, 14)),
+                    )
 
 
 class DurationTest(unittest.TestCase):
@@ -239,6 +257,11 @@ class DurationTest(unittest.TestCase):
                           date(2000, 1, 1))
         self.assertRaises(TypeError, operator.sub, 'raise exc',
                           Duration(years=1))
+        self.assertRaises(TypeError, operator.add,
+                          Duration(years=1, months=1, weeks=5),
+                          'raise exception')
+        self.assertRaises(TypeError, operator.add, 'raise exception',
+                          Duration(years=1, months=1, weeks=5))
 
     def test_parseerror(self):
         '''
@@ -289,7 +312,6 @@ class DurationTest(unittest.TestCase):
         self.assertEqual(duration_isoformat(dur), 'P3Y7M23DT5H25M0.33S')
         self.assertEqual(duration_isoformat(-dur), '-P3Y7M23DT5H25M0.33S')
 
-
     def test_equal(self):
         '''
         Test __eq__ and __ne__ methods.
@@ -313,6 +335,20 @@ class DurationTest(unittest.TestCase):
         #        treats a != b the same b != a
         #self.assertNotEqual(timedelta(days=1), Duration(days=1))
 
+    def test_totimedelta(self):
+        '''
+        Test conversion form Duration to timedelta.
+        '''
+        dur = Duration(years=1, months=2, days=10)
+        self.assertEqual(dur.totimedelta(datetime(1998, 2, 25)), timedelta(434))
+        # leap year has one day more in february
+        self.assertEqual(dur.totimedelta(datetime(2000, 2, 25)), timedelta(435))
+        dur = Duration(months=2)
+        # march is longer than february, but april is shorter than march (cause only one day difference compared to 2)
+        self.assertEqual(dur.totimedelta(datetime(2000, 2, 25)), timedelta(60))
+        self.assertEqual(dur.totimedelta(datetime(2001, 2, 25)), timedelta(59))
+        self.assertEqual(dur.totimedelta(datetime(2001, 3, 25)), timedelta(61))
+
 
 def create_parsetestcase(durationstring, expectation, format, altstr):
     """
@@ -451,7 +487,7 @@ def create_datecalctestcase(start, duration, expectation):
             Test operator +.
             '''
             if expectation is None:
-                self.assertRaises(TypeError, operator.add, start, duration)
+                self.assertRaises(ValueError, operator.add, start, duration)
             else:
                 self.assertEqual(start + duration, expectation)
 
@@ -475,5 +511,9 @@ def test_suite():
     suite.addTest(unittest.TestLoader().loadTestsFromTestCase(DurationTest))
     return suite
 
+# load_tests Protocol
+def load_tests(loader, tests, pattern):
+    return test_suite()
+
 if __name__ == '__main__':
     unittest.main(defaultTest='test_suite')
